import Vue from 'vue';
import Router from 'vue-router';
import { AuthGuard } from '@/utils';
import qs from 'qs';

Vue.use(Router);

const router = new Router({
    routes: [
        {
            path: '/indexview/:indexview?',
            beforeEnter: (to: any, from: any, next: any) => {
                const routerParamsName = 'indexview';
                const params: any = {};
                if (to.params && to.params[routerParamsName]) {
                    Object.assign(params, qs.parse(to.params[routerParamsName], { delimiter: ';' }));
                }
                const url: string = '/appdata';
                const auth: Promise<any> = AuthGuard.getInstance().authGuard(url, params, router);
                auth.then(() => {
                    next();
                }).catch(() => {
                    next();
                });
            },
            meta: {  
                caption: '流程应用',
                viewType: 'APPINDEX',
                parameters: [
                    { pathName: 'indexview', parameterName: 'indexview' },
                ],
                requireAuth: true,
            },
            component: () => import('@pages/ungroup/index-view/index-view.vue'),
            children: [
            {
                path: 'dewfdataredirectview/:dewfdataredirectview?',
                meta: {
                    caption: 'wfbm.views.wfdataredirectview.caption',
                    parameters: [
                        { pathName: 'wfbmwfdataredirectview', parameterName: 'wfbmwfdataredirectview' },
                    ],
                    requireAuth: true,
                },
                component: () => import('@pages/htwf/wfbmwfdata-redirect-view/wfbmwfdata-redirect-view.vue'),
            },
            {
                path: 'dewfdataredirectview/:dewfdataredirectview?',
                meta: {
                    caption: 'wfbc.views.wfdataredirectview.caption',
                    parameters: [
                        { pathName: 'wfbcwfdataredirectview', parameterName: 'wfbcwfdataredirectview' },
                    ],
                    requireAuth: true,
                },
                component: () => import('@pages/htwf/wfbcwfdata-redirect-view/wfbcwfdata-redirect-view.vue'),
            },
            {
                path: 'appwfdataredirectview/:appwfdataredirectview?',
                meta: {
                    caption: 'app.views.appwfredirectview.caption',
                    parameters: [
                        { pathName: 'appwfredirectview', parameterName: 'appwfredirectview' },
                    ],
                    requireAuth: true,
                },
                component: () => import('@pages/ungroup/app-wfredirect-view/app-wfredirect-view.vue'),
            },
            {
                path: 'dewfdataredirectview/:dewfdataredirectview?',
                meta: {
                    caption: 'wfim.views.wfdataredirectview.caption',
                    parameters: [
                        { pathName: 'wfimwfdataredirectview', parameterName: 'wfimwfdataredirectview' },
                    ],
                    requireAuth: true,
                },
                component: () => import('@pages/htwf/wfimwfdata-redirect-view/wfimwfdata-redirect-view.vue'),
            },
            ],
        },
    {
        path: '/orgusers/:orguser?/mpickupview/:mpickupview?',
        meta: {
            caption: 'orguser.views.mpickupview.caption',
            parameters: [
                { pathName: 'orgusers', parameterName: 'orguser' },
                { pathName: 'mpickupview', parameterName: 'mpickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/r7rt-org/org-user-mpickup-view/org-user-mpickup-view.vue'),
    },
            {
                path: '/dewfdataredirectview/:dewfdataredirectview?',
                meta: {
                    caption: 'wfbm.views.wfdataredirectview.caption',
                    parameters: [
                        { pathName: 'wfbmwfdataredirectview', parameterName: 'wfbmwfdataredirectview' },
                    ],
                    requireAuth: true,
                },
                component: () => import('@pages/htwf/wfbmwfdata-redirect-view/wfbmwfdata-redirect-view.vue'),
            },
    {
        path: '/wfas/:wfas?/editview/:editview?',
        meta: {
            caption: 'wfas.views.editview.caption',
            parameters: [
                { pathName: 'wfas', parameterName: 'wfas' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/htwf/wfasedit-view/wfasedit-view.vue'),
    },
    {
        path: '/wfiaactions/:wfiaaction?/addstepafteroptionview/:addstepafteroptionview?',
        meta: {
            caption: 'wfiaaction.views.addstepafteroptionview.caption',
            parameters: [
                { pathName: 'wfiaactions', parameterName: 'wfiaaction' },
                { pathName: 'addstepafteroptionview', parameterName: 'addstepafteroptionview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/r7rt-wf/wfiaaction-add-step-after-option-view/wfiaaction-add-step-after-option-view.vue'),
    },
    {
        path: '/wfstepdata/:wfstepdata?/editview/:editview?',
        meta: {
            caption: 'wfstepdata.views.editview.caption',
            parameters: [
                { pathName: 'wfstepdata', parameterName: 'wfstepdata' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/r7rt-wf/wfstepdataedit-view/wfstepdataedit-view.vue'),
    },
    {
        path: '/wfims/:wfim?/editview/:editview?',
        meta: {
            caption: 'wfim.views.editview.caption',
            parameters: [
                { pathName: 'wfims', parameterName: 'wfim' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/htwf/wfimedit-view/wfimedit-view.vue'),
    },
    {
        path: '/wfims/:wfim?/wfim_w10_wfeditview3/:wfim_w10_wfeditview3?',
        meta: {
            caption: 'wfim.views.wfim_w10_wfeditview3.caption',
            parameters: [
                { pathName: 'wfims', parameterName: 'wfim' },
                { pathName: 'wfim_w10_wfeditview3', parameterName: 'wfim_w10_wfeditview3' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/htwf/wfimwfim-w10-wfedit-view3/wfimwfim-w10-wfedit-view3.vue'),
    },
    {
        path: '/wfbms/:wfbm?/wfbm_w10_wfeditview3/:wfbm_w10_wfeditview3?',
        meta: {
            caption: 'wfbm.views.wfbm_w10_wfeditview3.caption',
            parameters: [
                { pathName: 'wfbms', parameterName: 'wfbm' },
                { pathName: 'wfbm_w10_wfeditview3', parameterName: 'wfbm_w10_wfeditview3' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/htwf/wfbmwfbm-w10-wfedit-view3/wfbmwfbm-w10-wfedit-view3.vue'),
    },
    {
        path: '/wfbcs/:wfbc?/wfproxydataview/:wfproxydataview?',
        meta: {
            caption: 'wfbc.views.wfproxydataview.caption',
            parameters: [
                { pathName: 'wfbcs', parameterName: 'wfbc' },
                { pathName: 'wfproxydataview', parameterName: 'wfproxydataview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/htwf/wfbcwfproxy-data-view/wfbcwfproxy-data-view.vue'),
    },
    {
        path: '/wfstepdata/:wfstepdata?/wfdatagridview9/:wfdatagridview9?',
        meta: {
            caption: 'wfstepdata.views.wfdatagridview9.caption',
            parameters: [
                { pathName: 'wfstepdata', parameterName: 'wfstepdata' },
                { pathName: 'wfdatagridview9', parameterName: 'wfdatagridview9' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/r7rt-wf/wfstepdatawfdata-grid-view9/wfstepdatawfdata-grid-view9.vue'),
    },
    {
        path: '/orgusers/:orguser?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'orguser.views.pickupgridview.caption',
            parameters: [
                { pathName: 'orgusers', parameterName: 'orguser' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/r7rt-org/org-user-pickup-grid-view/org-user-pickup-grid-view.vue'),
    },
    {
        path: '/wfbcs/:wfbc?/wfbc_w10_wfeditview3/:wfbc_w10_wfeditview3?',
        meta: {
            caption: 'wfbc.views.wfbc_w10_wfeditview3.caption',
            parameters: [
                { pathName: 'wfbcs', parameterName: 'wfbc' },
                { pathName: 'wfbc_w10_wfeditview3', parameterName: 'wfbc_w10_wfeditview3' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/htwf/wfbcwfbc-w10-wfedit-view3/wfbcwfbc-w10-wfedit-view3.vue'),
    },
            {
                path: '/dewfdataredirectview/:dewfdataredirectview?',
                meta: {
                    caption: 'wfbc.views.wfdataredirectview.caption',
                    parameters: [
                        { pathName: 'wfbcwfdataredirectview', parameterName: 'wfbcwfdataredirectview' },
                    ],
                    requireAuth: true,
                },
                component: () => import('@pages/htwf/wfbcwfdata-redirect-view/wfbcwfdata-redirect-view.vue'),
            },
    {
        path: '/wfiaactions/:wfiaaction?/addstepbeforeoptionview/:addstepbeforeoptionview?',
        meta: {
            caption: 'wfiaaction.views.addstepbeforeoptionview.caption',
            parameters: [
                { pathName: 'wfiaactions', parameterName: 'wfiaaction' },
                { pathName: 'addstepbeforeoptionview', parameterName: 'addstepbeforeoptionview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/r7rt-wf/wfiaaction-add-step-before-option-view/wfiaaction-add-step-before-option-view.vue'),
    },
    {
        path: '/wfiaactions/:wfiaaction?/sendbackoptionview/:sendbackoptionview?',
        meta: {
            caption: 'wfiaaction.views.sendbackoptionview.caption',
            parameters: [
                { pathName: 'wfiaactions', parameterName: 'wfiaaction' },
                { pathName: 'sendbackoptionview', parameterName: 'sendbackoptionview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/r7rt-wf/wfiaaction-sendback-option-view/wfiaaction-sendback-option-view.vue'),
    },
    {
        path: '/wfims/:wfim?/wfim_w30_wfeditview3/:wfim_w30_wfeditview3?',
        meta: {
            caption: 'wfim.views.wfim_w30_wfeditview3.caption',
            parameters: [
                { pathName: 'wfims', parameterName: 'wfim' },
                { pathName: 'wfim_w30_wfeditview3', parameterName: 'wfim_w30_wfeditview3' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/htwf/wfimwfim-w30-wfedit-view3/wfimwfim-w30-wfedit-view3.vue'),
    },
    {
        path: '/wfbms/:wfbm?/wfbm_w20_wfeditview3/:wfbm_w20_wfeditview3?',
        meta: {
            caption: 'wfbm.views.wfbm_w20_wfeditview3.caption',
            parameters: [
                { pathName: 'wfbms', parameterName: 'wfbm' },
                { pathName: 'wfbm_w20_wfeditview3', parameterName: 'wfbm_w20_wfeditview3' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/htwf/wfbmwfbm-w20-wfedit-view3/wfbmwfbm-w20-wfedit-view3.vue'),
    },
    {
        path: '/wfims/:wfim?/wfim_w40_wfeditview3/:wfim_w40_wfeditview3?',
        meta: {
            caption: 'wfim.views.wfim_w40_wfeditview3.caption',
            parameters: [
                { pathName: 'wfims', parameterName: 'wfim' },
                { pathName: 'wfim_w40_wfeditview3', parameterName: 'wfim_w40_wfeditview3' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/htwf/wfimwfim-w40-wfedit-view3/wfimwfim-w40-wfedit-view3.vue'),
    },
    {
        path: '/wfas/:wfas?/wfproxydataview/:wfproxydataview?',
        meta: {
            caption: 'wfas.views.wfproxydataview.caption',
            parameters: [
                { pathName: 'wfas', parameterName: 'wfas' },
                { pathName: 'wfproxydataview', parameterName: 'wfproxydataview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/htwf/wfaswfproxy-data-view/wfaswfproxy-data-view.vue'),
    },
    {
        path: '/wfims/:wfim?/wfim_d_wfeditview3/:wfim_d_wfeditview3?',
        meta: {
            caption: 'wfim.views.wfim_d_wfeditview3.caption',
            parameters: [
                { pathName: 'wfims', parameterName: 'wfim' },
                { pathName: 'wfim_d_wfeditview3', parameterName: 'wfim_d_wfeditview3' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/htwf/wfimwfim-d-wfedit-view3/wfimwfim-d-wfedit-view3.vue'),
    },
    {
        path: '/wfbms/:wfbm?/wfproxydataview/:wfproxydataview?',
        meta: {
            caption: 'wfbm.views.wfproxydataview.caption',
            parameters: [
                { pathName: 'wfbms', parameterName: 'wfbm' },
                { pathName: 'wfproxydataview', parameterName: 'wfproxydataview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/htwf/wfbmwfproxy-data-view/wfbmwfproxy-data-view.vue'),
    },
    {
        path: '/wfims/:wfim?/wfim_w90_wfeditview3/:wfim_w90_wfeditview3?',
        meta: {
            caption: 'wfim.views.wfim_w90_wfeditview3.caption',
            parameters: [
                { pathName: 'wfims', parameterName: 'wfim' },
                { pathName: 'wfim_w90_wfeditview3', parameterName: 'wfim_w90_wfeditview3' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/htwf/wfimwfim-w90-wfedit-view3/wfimwfim-w90-wfedit-view3.vue'),
    },
    {
        path: '/wfbms/:wfbm?/wfbm_d_wfeditview3/:wfbm_d_wfeditview3?',
        meta: {
            caption: 'wfbm.views.wfbm_d_wfeditview3.caption',
            parameters: [
                { pathName: 'wfbms', parameterName: 'wfbm' },
                { pathName: 'wfbm_d_wfeditview3', parameterName: 'wfbm_d_wfeditview3' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/htwf/wfbmwfbm-d-wfedit-view3/wfbmwfbm-d-wfedit-view3.vue'),
    },
    {
        path: '/wfims/:wfim?/wfim_w80_wfeditview3/:wfim_w80_wfeditview3?',
        meta: {
            caption: 'wfim.views.wfim_w80_wfeditview3.caption',
            parameters: [
                { pathName: 'wfims', parameterName: 'wfim' },
                { pathName: 'wfim_w80_wfeditview3', parameterName: 'wfim_w80_wfeditview3' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/htwf/wfimwfim-w80-wfedit-view3/wfimwfim-w80-wfedit-view3.vue'),
    },
    {
        path: '/wfims/:wfim?/wfim_w50_wfeditview3/:wfim_w50_wfeditview3?',
        meta: {
            caption: 'wfim.views.wfim_w50_wfeditview3.caption',
            parameters: [
                { pathName: 'wfims', parameterName: 'wfim' },
                { pathName: 'wfim_w50_wfeditview3', parameterName: 'wfim_w50_wfeditview3' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/htwf/wfimwfim-w50-wfedit-view3/wfimwfim-w50-wfedit-view3.vue'),
    },
    {
        path: '/wfims/:wfim?/wfim_w20_wfeditview3/:wfim_w20_wfeditview3?',
        meta: {
            caption: 'wfim.views.wfim_w20_wfeditview3.caption',
            parameters: [
                { pathName: 'wfims', parameterName: 'wfim' },
                { pathName: 'wfim_w20_wfeditview3', parameterName: 'wfim_w20_wfeditview3' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/htwf/wfimwfim-w20-wfedit-view3/wfimwfim-w20-wfedit-view3.vue'),
    },
    {
        path: '/wfims/:wfim?/wfim_w70_wfeditview3/:wfim_w70_wfeditview3?',
        meta: {
            caption: 'wfim.views.wfim_w70_wfeditview3.caption',
            parameters: [
                { pathName: 'wfims', parameterName: 'wfim' },
                { pathName: 'wfim_w70_wfeditview3', parameterName: 'wfim_w70_wfeditview3' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/htwf/wfimwfim-w70-wfedit-view3/wfimwfim-w70-wfedit-view3.vue'),
    },
            {
                path: '/appwfdataredirectview/:appwfdataredirectview?',
                meta: {
                    caption: 'app.views.appwfredirectview.caption',
                    parameters: [
                        { pathName: 'appwfredirectview', parameterName: 'appwfredirectview' },
                    ],
                    requireAuth: true,
                },
                component: () => import('@pages/ungroup/app-wfredirect-view/app-wfredirect-view.vue'),
            },
    {
        path: '/wfbcs/:wfbc?/wfbc_d_wfeditview3/:wfbc_d_wfeditview3?',
        meta: {
            caption: 'wfbc.views.wfbc_d_wfeditview3.caption',
            parameters: [
                { pathName: 'wfbcs', parameterName: 'wfbc' },
                { pathName: 'wfbc_d_wfeditview3', parameterName: 'wfbc_d_wfeditview3' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/htwf/wfbcwfbc-d-wfedit-view3/wfbcwfbc-d-wfedit-view3.vue'),
    },
    {
        path: '/wfims/:wfim?/wfproxydataview/:wfproxydataview?',
        meta: {
            caption: 'wfim.views.wfproxydataview.caption',
            parameters: [
                { pathName: 'wfims', parameterName: 'wfim' },
                { pathName: 'wfproxydataview', parameterName: 'wfproxydataview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/htwf/wfimwfproxy-data-view/wfimwfproxy-data-view.vue'),
    },
    {
        path: '/wfbcs/:wfbc?/editview/:editview?',
        meta: {
            caption: 'wfbc.views.editview.caption',
            parameters: [
                { pathName: 'wfbcs', parameterName: 'wfbc' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/htwf/wfbcedit-view/wfbcedit-view.vue'),
    },
    {
        path: '/wfbms/:wfbm?/editview/:editview?',
        meta: {
            caption: 'wfbm.views.editview.caption',
            parameters: [
                { pathName: 'wfbms', parameterName: 'wfbm' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/htwf/wfbmedit-view/wfbmedit-view.vue'),
    },
            {
                path: '/dewfdataredirectview/:dewfdataredirectview?',
                meta: {
                    caption: 'wfim.views.wfdataredirectview.caption',
                    parameters: [
                        { pathName: 'wfimwfdataredirectview', parameterName: 'wfimwfdataredirectview' },
                    ],
                    requireAuth: true,
                },
                component: () => import('@pages/htwf/wfimwfdata-redirect-view/wfimwfdata-redirect-view.vue'),
            },
    {
        path: '/wfas/:wfas?/wfas_w10_wfeditview3/:wfas_w10_wfeditview3?',
        meta: {
            caption: 'wfas.views.wfas_w10_wfeditview3.caption',
            parameters: [
                { pathName: 'wfas', parameterName: 'wfas' },
                { pathName: 'wfas_w10_wfeditview3', parameterName: 'wfas_w10_wfeditview3' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/htwf/wfaswfas-w10-wfedit-view3/wfaswfas-w10-wfedit-view3.vue'),
    },
        {
            path: '/login/:login?',
            name: 'login',
            meta: {  
                caption: '登录',
                viewType: 'login',
                requireAuth: false,
                ignoreAddPage: true,
            },
            beforeEnter: (to: any, from: any, next: any) => {
                router.app.$store.commit('resetRootStateData');
                next();
            },
            component: () => import('@components/login/login.vue'),
        },
        {
            path: '/404',
            component: () => import('@components/404/404.vue')
        },
        {
            path: '/500',
            component: () => import('@components/500/500.vue')
        },
        {
            path: '*',
            redirect: 'indexview'
        },
    ],
});

export default router;
